#
# PySNMP MIB module MPLS-LSR-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-LSR-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:00 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( AddressFamilyNumbers, ) = mibBuilder.importSymbols("IANA-ADDRESS-FAMILY-NUMBERS-MIB", "AddressFamilyNumbers")
( ifCounterDiscontinuityGroup, ifGeneralInformationGroup, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "ifCounterDiscontinuityGroup", "ifGeneralInformationGroup", "InterfaceIndexOrZero")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( MplsOwner, MplsLabel, MplsLSPID, MplsBitRate, mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "MplsOwner", "MplsLabel", "MplsLSPID", "MplsBitRate", "mplsStdMIB")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( IpAddress, Unsigned32, Counter32, iso, Counter64, TimeTicks, zeroDotZero, ModuleIdentity, Bits, Gauge32, NotificationType, ObjectIdentity, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Unsigned32", "Counter32", "iso", "Counter64", "TimeTicks", "zeroDotZero", "ModuleIdentity", "Bits", "Gauge32", "NotificationType", "ObjectIdentity", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32")
( TextualConvention, TimeStamp, RowStatus, StorageType, RowPointer, TruthValue, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "TimeStamp", "RowStatus", "StorageType", "RowPointer", "TruthValue", "DisplayString")
mplsLsrStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 2)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsLsrStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsLsrStdMIB.setOrganization('Multiprotocol Label Switching (MPLS) Working Group')
if mibBuilder.loadTexts: mplsLsrStdMIB.setContactInfo('        Cheenu Srinivasan\n                     Bloomberg L.P.\n             Email:  cheenu@bloomberg.net\n            \n                     Arun Viswanathan\n                     Force10 Networks, Inc.\n             Email:  arunv@force10networks.com\n            \n                     Thomas D. Nadeau\n                     Cisco Systems, Inc.\n             Email:  tnadeau@cisco.com\n            \n             Comments about this document should be emailed\n             directly to the MPLS working group mailing list at\n             mpls@uu.net.')
if mibBuilder.loadTexts: mplsLsrStdMIB.setDescription('This MIB module contains managed object definitions for\n             the Multiprotocol Label Switching (MPLS) Router as\n             defined in: Rosen, E., Viswanathan, A., and R.\n             Callon, Multiprotocol Label Switching Architecture,\n             RFC 3031, January 2001.\n            \n             Copyright (C) The Internet Society (2004). The\n             initial version of this MIB module was published\n             in RFC 3812. For full legal notices see the RFC\n             itself or see:\n             http://www.ietf.org/copyrights/ianamib.html')
class MplsIndexType(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,24)

class MplsIndexNextType(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,24)

mplsLsrNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 2, 0))
mplsLsrObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 2, 1))
mplsLsrConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 2, 2))
mplsInterfaceTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1), )
if mibBuilder.loadTexts: mplsInterfaceTable.setDescription('This table specifies per-interface MPLS capability\n             and associated information.')
mplsInterfaceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsInterfaceIndex"))
if mibBuilder.loadTexts: mplsInterfaceEntry.setDescription('A conceptual row in this table is created\n             automatically by an LSR for every interface capable\n             of supporting MPLS and which is configured to do so.\n             A conceptual row in this table will exist if and only if\n             a corresponding entry in ifTable exists with ifType =\n             mpls(166). If this associated entry in ifTable is\n             operationally disabled (thus removing MPLS\n             capabilities on that interface), the corresponding\n             entry in this table MUST be deleted shortly thereafter.\n             An conceptual row with index 0 is created if the LSR\n             supports per-platform labels. This conceptual row\n             represents the per-platform label space and contains\n             parameters that apply to all interfaces that participate\n             in the per-platform label space. Other conceptual rows\n             in this table represent MPLS interfaces that may\n             participate in either the per-platform or per-\n             interface label spaces, or both.  Implementations\n             that either only support per-platform labels,\n             or have only them configured, may choose to return\n             just the mplsInterfaceEntry of 0 and not return\n             the other rows. This will greatly reduce the number\n             of objects returned. Further information about label\n             space participation of an interface is provided in\n             the DESCRIPTION clause of\n             mplsInterfaceLabelParticipationType.')
mplsInterfaceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 1), InterfaceIndexOrZero())
if mibBuilder.loadTexts: mplsInterfaceIndex.setDescription('This is a unique index for an entry in the\n             MplsInterfaceTable.  A non-zero index for an\n             entry indicates the ifIndex for the corresponding\n             interface entry of the MPLS-layer in the ifTable.\n             The entry with index 0 represents the per-platform\n             label space and contains parameters that apply to all\n             interfaces that participate in the per-platform label\n             space. Other entries defined in this table represent\n             additional MPLS interfaces that may participate in either\n             the per-platform or per-interface label spaces, or both.')
mplsInterfaceLabelMinIn = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 2), MplsLabel()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceLabelMinIn.setDescription('This is the minimum value of an MPLS label that this\n             LSR is willing to receive on this interface.')
mplsInterfaceLabelMaxIn = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 3), MplsLabel()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceLabelMaxIn.setDescription('This is the maximum value of an MPLS label that this\n             LSR is willing to receive on this interface.')
mplsInterfaceLabelMinOut = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 4), MplsLabel()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceLabelMinOut.setDescription('This is the minimum value of an MPLS label that this\n             LSR is willing to send on this interface.')
mplsInterfaceLabelMaxOut = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 5), MplsLabel()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceLabelMaxOut.setDescription('This is the maximum value of an MPLS label that this\n             LSR is willing to send on this interface.')
mplsInterfaceTotalBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 6), MplsBitRate()).setUnits('kilobits per second').setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceTotalBandwidth.setDescription('This value indicates the total amount of usable\n             bandwidth on this interface and is specified in\n             kilobits per second (Kbps).  This variable is not\n             applicable when applied to the interface with index\n             0. When this value cannot be measured, this value\n             should contain the nominal bandwidth.')
mplsInterfaceAvailableBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 7), MplsBitRate()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceAvailableBandwidth.setDescription('This value indicates the total amount of available\n             bandwidth available on this interface and is\n             specified in kilobits per second (Kbps).  This value\n             is calculated as the difference between the amount\n             of bandwidth currently in use and that specified in\n             mplsInterfaceTotalBandwidth.  This variable is not\n             applicable when applied to the interface with index\n             0. When this value cannot be measured, this value\n             should contain the nominal bandwidth.')
mplsInterfaceLabelParticipationType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 1, 1, 8), Bits().clone(namedValues=NamedValues(("perPlatform", 0), ("perInterface", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfaceLabelParticipationType.setDescription('If the value of the mplsInterfaceIndex for this\n             entry is zero, then this entry corresponds to the\n             per-platform label space for all interfaces configured\n             to use that label space. In this case the perPlatform(0)\n             bit MUST be set; the perInterface(1) bit is meaningless\n             and MUST be ignored.\n    \n             The remainder of this description applies to entries\n             with a non-zero value of mplsInterfaceIndex.\n    \n             If the perInterface(1) bit is set then the value of\n             mplsInterfaceLabelMinIn, mplsInterfaceLabelMaxIn,\n             mplsInterfaceLabelMinOut, and\n             mplsInterfaceLabelMaxOut for this entry reflect the\n             label ranges for this interface.\n    \n             If only the perPlatform(0) bit is set, then the value of\n             mplsInterfaceLabelMinIn, mplsInterfaceLabelMaxIn,\n             mplsInterfaceLabelMinOut, and\n             mplsInterfaceLabelMaxOut for this entry MUST be\n             identical to the instance of these objects with\n             index 0.  These objects may only vary from the entry\n             with index 0 if both the perPlatform(0) and perInterface(1)\n             bits are set.\n    \n             In all cases, at a minimum one of the perPlatform(0) or\n             perInterface(1) bits MUST be set to indicate that\n             at least one label space is in use by this interface. In\n             all cases, agents MUST ensure that label ranges are\n             specified consistently and MUST return an\n             inconsistentValue error when they do not.')
mplsInterfacePerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2), )
if mibBuilder.loadTexts: mplsInterfacePerfTable.setDescription('This table provides MPLS performance information on\n             a per-interface basis.')
mplsInterfacePerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2, 1), )
mplsInterfaceEntry.registerAugmentions(("MPLS-LSR-STD-MIB", "mplsInterfacePerfEntry"))
mplsInterfacePerfEntry.setIndexNames(*mplsInterfaceEntry.getIndexNames())
if mibBuilder.loadTexts: mplsInterfacePerfEntry.setDescription("An entry in this table is created by the LSR for\n             every interface capable of supporting MPLS.  Its is\n             an extension to the mplsInterfaceEntry table.\n             Note that the discontinuity behavior of entries in\n             this table MUST be based on the corresponding\n             ifEntry's ifDiscontinuityTime.")
mplsInterfacePerfInLabelsInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfacePerfInLabelsInUse.setDescription('This object counts the number of labels that are in\n             use at this point in time on this interface in the\n             incoming direction. If the interface participates in\n             only the per-platform label space, then the value of\n             the instance of this object MUST be identical to\n             the value of the instance with index 0. If the\n             interface participates in the per-interface label\n             space, then the instance of this object MUST\n             represent the number of per-interface labels that\n             are in use on this interface.')
mplsInterfacePerfInLabelLookupFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfacePerfInLabelLookupFailures.setDescription('This object counts the number of labeled packets\n             that have been received on this interface and which\n             were discarded because there was no matching cross-\n             connect entry. This object MUST count on a per-\n             interface basis regardless of which label space the\n             interface participates in.')
mplsInterfacePerfOutLabelsInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfacePerfOutLabelsInUse.setDescription('This object counts the number of top-most labels in\n             the outgoing label stacks that are in use at this\n             point in time on this interface. This object MUST\n             count on a per-interface basis regardless of which\n             label space the interface participates in.')
mplsInterfacePerfOutFragmentedPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInterfacePerfOutFragmentedPkts.setDescription('This object counts the number of outgoing MPLS\n             packets that required fragmentation before\n             transmission on this interface. This object MUST\n             count on a per-interface basis regardless of which\n             label space the interface participates in.')
mplsInSegmentIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 3), MplsIndexNextType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentIndexNext.setDescription('This object contains the next available value to\n             be used for mplsInSegmentIndex when creating entries\n             in the mplsInSegmentTable. The special value of a\n             string containing the single octet 0x00 indicates\n             that no new entries can be created in this table.\n             Agents not allowing managers to create entries\n             in this table MUST set this object to this special\n             value.')
mplsInSegmentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4), )
if mibBuilder.loadTexts: mplsInSegmentTable.setDescription("This table contains a description of the incoming MPLS\n             segments (labels) to an LSR and their associated parameters.\n             The index for this table is mplsInSegmentIndex.\n             The index structure of this table is specifically designed\n             to handle many different MPLS implementations that manage\n             their labels both in a distributed and centralized manner.\n             The table is also designed to handle existing MPLS labels\n             as defined in RFC3031 as well as longer ones that may\n             be necessary in the future.\n    \n             In cases where the label cannot fit into the\n             mplsInSegmentLabel object, the mplsInSegmentLabelPtr\n             will indicate this by being set to the first accessible\n             column in the appropriate extension table's row.\n             In this case an additional table MUST\n             be provided and MUST be indexed by at least the indexes\n             used by this table. In all other cases when the label is\n             represented within the mplsInSegmentLabel object, the\n             mplsInSegmentLabelPtr MUST be set to 0.0. Due to the\n             fact that MPLS labels may not exceed 24 bits, the\n             mplsInSegmentLabelPtr object is only a provision for\n             future-proofing the MIB module. Thus, the definition\n             of any extension tables is beyond the scope of this\n             MIB module.")
mplsInSegmentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsInSegmentIndex"))
if mibBuilder.loadTexts: mplsInSegmentEntry.setDescription("An entry in this table represents one incoming\n             segment as is represented in an LSR's LFIB.\n             An entry can be created by a network\n             administrator or an SNMP agent, or an MPLS signaling\n             protocol.  The creator of the entry is denoted by\n             mplsInSegmentOwner.\n             The value of mplsInSegmentRowStatus cannot be active(1)\n             unless the ifTable entry corresponding to\n             mplsInSegmentInterface exists.  An entry in this table\n             must match any incoming packets, and indicates an\n             instance of mplsXCEntry based on which forwarding\n             and/or switching actions are taken.")
mplsInSegmentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsInSegmentIndex.setDescription('The index for this in-segment. The\n             string containing the single octet 0x00\n             MUST not be used as an index.')
mplsInSegmentInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 2), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentInterface.setDescription('This object represents the\n             interface index for the incoming MPLS interface.  A\n             value of zero represents all interfaces participating in\n             the per-platform label space.  This may only be used\n             in cases where the incoming interface and label\n             are associated with the same mplsXCEntry. Specifically,\n             given a label and any incoming interface pair from the\n             per-platform label space, the outgoing label/interface\n             mapping remains the same. If this is not the case,\n             then individual entries MUST exist that\n             can then be mapped to unique mplsXCEntries.')
mplsInSegmentLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 3), MplsLabel()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentLabel.setDescription('If the corresponding instance of mplsInSegmentLabelPtr is\n             zeroDotZero then this object MUST contain the incoming label\n             associated with this in-segment. If not this object SHOULD\n             be zero and MUST be ignored.')
mplsInSegmentLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 4), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentLabelPtr.setDescription('If the label for this segment cannot be represented\n             fully within the mplsInSegmentLabel object,\n             this object MUST point to the first accessible\n             column of a conceptual row in an external table containing\n             the label.  In this case, the mplsInSegmentTopLabel\n             object SHOULD be set to 0 and ignored. This object MUST\n             be set to zeroDotZero otherwise.')
mplsInSegmentNPop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)).clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentNPop.setDescription('The number of labels to pop from the incoming\n             packet.  Normally only the top label is popped from\n             the packet and used for all switching decisions for\n             that packet.  This is indicated by setting this\n             object to the default value of 1. If an LSR supports\n             popping of more than one label, this object MUST\n             be set to that number. This object cannot be modified\n             if mplsInSegmentRowStatus is active(1).')
mplsInSegmentAddrFamily = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 6), AddressFamilyNumbers().clone('other')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentAddrFamily.setDescription('The IANA address family [IANAFamily] of packets\n             received on this segment, which is used at an egress\n             LSR to deliver them to the appropriate layer 3 entity.\n             A value of other(0) indicates that the family type is\n             either unknown or undefined; this SHOULD NOT be used\n             at an egress LSR. This object cannot be\n             modified if mplsInSegmentRowStatus is active(1).')
mplsInSegmentXCIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 7), MplsIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentXCIndex.setDescription('Index into mplsXCTable which identifies which cross-\n             connect entry this segment is part of.  The string\n             containing the single octet 0x00 indicates that this\n             entry is not referred to by any cross-connect entry.\n             When a cross-connect entry is created which this\n             in-segment is a part of, this object is automatically\n             updated to reflect the value of mplsXCIndex of that\n             cross-connect entry.')
mplsInSegmentOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 8), MplsOwner()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentOwner.setDescription('Denotes the entity that created and is responsible\n             for managing this segment.')
mplsInSegmentTrafficParamPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 9), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentTrafficParamPtr.setDescription('This variable represents a pointer to the traffic\n             parameter specification for this in-segment.  This\n             value may point at an entry in the\n             mplsTunnelResourceTable in the MPLS-TE-STD-MIB (RFC3812)\n             to indicate which traffic parameter settings for this\n             segment if it represents an LSP used for a TE tunnel.\n            \n             This value may optionally point at an\n             externally defined traffic parameter specification\n             table.  A value of zeroDotZero indicates best-effort\n             treatment.  By having the same value of this object,\n             two or more segments can indicate resource sharing\n             of such things as LSP queue space, etc.\n            \n             This object cannot be modified if mplsInSegmentRowStatus\n             is active(1).  For entries in this table that\n             are preserved after a re-boot, the agent MUST ensure\n             that their integrity be preserved, or this object should\n             be set to 0.0 if it cannot.')
mplsInSegmentRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 10), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentRowStatus.setDescription('This variable is used to create, modify, and/or\n             delete a row in this table. When a row in this\n             table has a row in the active(1) state, no\n             objects in this row can be modified except the\n             mplsInSegmentRowStatus and mplsInSegmentStorageType.')
mplsInSegmentStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 4, 1, 11), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsInSegmentStorageType.setDescription("This variable indicates the storage type for this\n             object. The agent MUST ensure that this object's\n             value remains consistent with the associated\n             mplsXCEntry. Conceptual rows having the value\n             'permanent' need not allow write-access to any\n             columnar objects in the row.")
mplsInSegmentPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5), )
if mibBuilder.loadTexts: mplsInSegmentPerfTable.setDescription('This table contains statistical information for\n             incoming MPLS segments to an LSR.')
mplsInSegmentPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1), )
mplsInSegmentEntry.registerAugmentions(("MPLS-LSR-STD-MIB", "mplsInSegmentPerfEntry"))
mplsInSegmentPerfEntry.setIndexNames(*mplsInSegmentEntry.getIndexNames())
if mibBuilder.loadTexts: mplsInSegmentPerfEntry.setDescription('An entry in this table contains statistical\n             information about one incoming segment which is\n             configured in the mplsInSegmentTable. The counters\n             in this entry should behave in a manner similar to\n             that of the interface.\n             mplsInSegmentPerfDiscontinuityTime indicates the\n             time of the last discontinuity in all of these\n             objects.')
mplsInSegmentPerfOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfOctets.setDescription('This value represents the total number of octets\n             received by this segment. It MUST be equal to the\n             least significant 32 bits of\n             mplsInSegmentPerfHCOctets\n             if mplsInSegmentPerfHCOctets is supported according to\n             the rules spelled out in RFC2863.')
mplsInSegmentPerfPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfPackets.setDescription('Total number of packets received by this segment.')
mplsInSegmentPerfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfErrors.setDescription('The number of errored packets received on this\n             segment.')
mplsInSegmentPerfDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfDiscards.setDescription('The number of labeled packets received on this in-\n             segment, which were chosen to be discarded even\n             though no errors had been detected to prevent their\n             being transmitted.  One possible reason for\n             discarding such a labeled packet could be to free up\n             buffer space.')
mplsInSegmentPerfHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfHCOctets.setDescription('The total number of octets received.  This is the 64\n             bit version of mplsInSegmentPerfOctets,\n             if mplsInSegmentPerfHCOctets is supported according to\n             the rules spelled out in RFC2863.')
mplsInSegmentPerfDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 5, 1, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentPerfDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion\n             at which any one or more of this segment's Counter32\n             or Counter64 suffered a discontinuity. If no such\n             discontinuities have occurred since the last re-\n             initialization of the local management subsystem,\n             then this object contains a zero value.")
mplsOutSegmentIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 6), MplsIndexNextType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentIndexNext.setDescription('This object contains the next available value to\n             be used for mplsOutSegmentIndex when creating entries\n             in the mplsOutSegmentTable. The special value of a\n             string containing the single octet 0x00\n             indicates that no new entries can be created in this\n             table. Agents not allowing managers to create entries\n             in this table MUST set this object to this special\n             value.')
mplsOutSegmentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7), )
if mibBuilder.loadTexts: mplsOutSegmentTable.setDescription('This table contains a representation of the outgoing\n             segments from an LSR.')
mplsOutSegmentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsOutSegmentIndex"))
if mibBuilder.loadTexts: mplsOutSegmentEntry.setDescription('An entry in this table represents one outgoing\n             segment.  An entry can be created by a network\n             administrator, an SNMP agent, or an MPLS signaling\n             protocol.  The object mplsOutSegmentOwner indicates\n             the creator of this entry. The value of\n             mplsOutSegmentRowStatus cannot be active(1) unless\n             the ifTable entry corresponding to\n             mplsOutSegmentInterface exists.\n    \n             Note that the indexing of this table uses a single,\n             arbitrary index (mplsOutSegmentIndex) to indicate\n             which out-segment (i.e.: label) is being switched to\n             from which in-segment (i.e: label) or in-segments.\n             This is necessary because it is possible to have an\n             equal-cost multi-path situation where two identical\n             out-going labels are assigned to the same\n             cross-connect (i.e.: they go to two different neighboring\n             LSRs); thus, requiring two out-segments. In order to\n             preserve the uniqueness of the references\n             by the mplsXCEntry, an arbitrary integer must be used as\n             the index for this table.')
mplsOutSegmentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsOutSegmentIndex.setDescription('This value contains a unique index for this row.\n             While a value of a string containing the single\n             octet 0x00 is not valid as an index for entries\n             in this table, it can be supplied as a valid value\n             to index the mplsXCTable to represent entries for\n             which no out-segment has been configured or\n             exists.')
mplsOutSegmentInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 2), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentInterface.setDescription('This value must contain the interface index of the\n             outgoing interface. This object cannot be modified\n             if mplsOutSegmentRowStatus is active(1). The\n             mplsOutSegmentRowStatus cannot be set to active(1)\n             until this object is set to a value corresponding to\n             a valid ifEntry.')
mplsOutSegmentPushTopLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 3), TruthValue().clone('true')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentPushTopLabel.setDescription("This value indicates whether or not a top label\n             should be pushed onto the outgoing packet's label\n             stack.  The value of this variable MUST be set to\n             true(1) if the outgoing interface does not support\n             pop-and-go (and no label stack remains). For example,\n             on ATM interface, or if the segment represents a\n             tunnel origination.  Note that it is considered\n             an error in the case that mplsOutSegmentPushTopLabel\n             is set to false, but the cross-connect entry which\n             refers to this out-segment has a non-zero\n             mplsLabelStackIndex.  The LSR MUST ensure that this\n             situation does not happen. This object cannot be\n             modified if mplsOutSegmentRowStatus is active(1).")
mplsOutSegmentTopLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 4), MplsLabel()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentTopLabel.setDescription("If mplsOutSegmentPushTopLabel is true then this\n             represents the label that should be pushed onto the\n             top of the outgoing packet's label stack. Otherwise\n             this value SHOULD be set to 0 by the management\n             station and MUST be ignored by the agent. This\n             object cannot be modified if mplsOutSegmentRowStatus\n             is active(1).")
mplsOutSegmentTopLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 5), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentTopLabelPtr.setDescription('If the label for this segment cannot be represented\n             fully within the mplsOutSegmentLabel object,\n             this object MUST point to the first accessible\n             column of a conceptual row in an external table containing\n             the label.  In this case, the mplsOutSegmentTopLabel\n             object SHOULD be set to 0 and ignored. This object\n             MUST be set to zeroDotZero otherwise.')
mplsOutSegmentNextHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 6), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentNextHopAddrType.setDescription('Indicates the next hop Internet address type.\n             Only values unknown(0), ipv4(1) or ipv6(2)\n             have to be supported.\n    \n             A value of unknown(0) is allowed only when\n             the outgoing interface is of type point-to-point.\n             If any other unsupported values are attempted in a set\n             operation, the agent MUST return an inconsistentValue\n             error.')
mplsOutSegmentNextHopAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 7), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentNextHopAddr.setDescription('The internet address of the next hop. The type of\n             this address is determined by the value of the\n             mplslOutSegmentNextHopAddrType object.\n    \n             This object cannot be modified if\n             mplsOutSegmentRowStatus is active(1).')
mplsOutSegmentXCIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 8), MplsIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentXCIndex.setDescription('Index into mplsXCTable which identifies which cross-\n             connect entry this segment is part of.  A value of\n             the string containing the single octet 0x00\n             indicates that this entry is not referred\n             to by any cross-connect entry.  When a cross-connect\n             entry is created which this out-segment is a part of,\n             this object MUST be updated by the agent to reflect\n             the value of mplsXCIndex of that cross-connect\n             entry.')
mplsOutSegmentOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 9), MplsOwner()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentOwner.setDescription('Denotes the entity which created and is responsible\n             for managing this segment.')
mplsOutSegmentTrafficParamPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 10), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentTrafficParamPtr.setDescription('This variable represents a pointer to the traffic\n             parameter specification for this out-segment.  This\n             value may point at an entry in the\n             MplsTunnelResourceEntry in the MPLS-TE-STD-MIB (RFC3812)\n            \n             RFC Editor: Please fill in RFC number.\n            \n             to indicate which traffic parameter settings for this\n             segment if it represents an LSP used for a TE tunnel.\n            \n             This value may optionally point at an\n             externally defined traffic parameter specification\n             table.  A value of zeroDotZero indicates best-effort\n             treatment.  By having the same value of this object,\n             two or more segments can indicate resource sharing\n             of such things as LSP queue space, etc.\n            \n             This object cannot be modified if\n             mplsOutSegmentRowStatus is active(1).\n             For entries in this table that\n             are preserved after a re-boot, the agent MUST ensure\n             that their integrity be preserved, or this object should\n             be set to 0.0 if it cannot.')
mplsOutSegmentRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentRowStatus.setDescription('For creating, modifying, and deleting this row.\n             When a row in this table has a row in the active(1)\n             state, no objects in this row can be modified\n             except the mplsOutSegmentRowStatus or\n             mplsOutSegmentStorageType.')
mplsOutSegmentStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 7, 1, 12), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsOutSegmentStorageType.setDescription("This variable indicates the storage type for this\n             object. The agent MUST ensure that this object's value\n             remains consistent with the associated mplsXCEntry.\n             Conceptual rows having the value 'permanent'\n             need not allow write-access to any columnar\n             objects in the row.")
mplsOutSegmentPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8), )
if mibBuilder.loadTexts: mplsOutSegmentPerfTable.setDescription('This table contains statistical information about\n             outgoing segments from an LSR. The counters in this\n             entry should behave in a manner similar to that of\n             the interface.')
mplsOutSegmentPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1), )
mplsOutSegmentEntry.registerAugmentions(("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfEntry"))
mplsOutSegmentPerfEntry.setIndexNames(*mplsOutSegmentEntry.getIndexNames())
if mibBuilder.loadTexts: mplsOutSegmentPerfEntry.setDescription('An entry in this table contains statistical\n             information about one outgoing segment configured in\n             mplsOutSegmentTable. The object\n             mplsOutSegmentPerfDiscontinuityTime indicates the\n             time of the last discontinuity in these objects. ')
mplsOutSegmentPerfOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfOctets.setDescription('This value contains the total number of octets sent\n             on this segment. It MUST be equal to the least\n             significant 32 bits of mplsOutSegmentPerfHCOctets\n             if mplsOutSegmentPerfHCOctets is supported according to\n             the rules spelled out in RFC2863.')
mplsOutSegmentPerfPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfPackets.setDescription('This value contains the total number of packets sent\n             on this segment.')
mplsOutSegmentPerfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfErrors.setDescription('Number of packets that could not be sent due to\n             errors on this segment.')
mplsOutSegmentPerfDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfDiscards.setDescription('The number of labeled packets attempted to be transmitted\n             on this out-segment, which were chosen to be discarded\n             even though no errors had been detected to prevent their\n             being transmitted. One possible reason for\n             discarding such a labeled packet could be to free up\n             buffer space.')
mplsOutSegmentPerfHCOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfHCOctets.setDescription('Total number of octets sent.  This is the 64 bit\n             version of mplsOutSegmentPerfOctets,\n             if mplsOutSegmentPerfHCOctets is supported according to\n             the rules spelled out in RFC2863.')
mplsOutSegmentPerfDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 8, 1, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsOutSegmentPerfDiscontinuityTime.setDescription("The value of sysUpTime on the most recent occasion\n             at which any one or more of this segment's Counter32\n             or Counter64 suffered a discontinuity. If no such\n             discontinuities have occurred since the last re-\n             initialization of the local management subsystem,\n             then this object contains a zero value.")
mplsXCIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 9), MplsIndexNextType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsXCIndexNext.setDescription('This object contains the next available value to\n             be used for mplsXCIndex when creating entries in\n             the mplsXCTable. A special value of the zero length\n             string indicates that no more new entries can be created\n             in the relevant table.  Agents not allowing managers\n             to create entries in this table MUST set this value\n             to the zero length string.')
mplsXCTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10), )
if mibBuilder.loadTexts: mplsXCTable.setDescription('This table specifies information for switching\n             between LSP segments.  It supports point-to-point,\n             point-to-multipoint and multipoint-to-point\n             connections.  mplsLabelStackTable specifies the\n             label stack information for a cross-connect LSR and\n             is referred to from mplsXCTable.')
mplsXCEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsXCIndex"), (0, "MPLS-LSR-STD-MIB", "mplsXCInSegmentIndex"), (0, "MPLS-LSR-STD-MIB", "mplsXCOutSegmentIndex"))
if mibBuilder.loadTexts: mplsXCEntry.setDescription('A row in this table represents one cross-connect\n             entry.  It is indexed by the following objects:\n    \n             - cross-connect index mplsXCIndex that uniquely\n               identifies a group of cross-connect entries\n    \n             - in-segment index, mplsXCInSegmentIndex\n    \n             - out-segment index, mplsXCOutSegmentIndex\n    \n            LSPs originating at this LSR:\n             These are represented by using the special\n             of value of mplsXCInSegmentIndex set to the\n             string containing a single octet 0x00. In\n             this case the mplsXCOutSegmentIndex\n             MUST not be the string containing a single\n             octet 0x00.\n    \n            LSPs terminating at this LSR:\n             These are represented by using the special value\n             mplsXCOutSegmentIndex set to the string containing\n             a single octet 0x00.\n    \n            Special labels:\n             Entries indexed by the strings containing the\n             reserved MPLS label values as a single octet 0x00\n             through 0x0f (inclusive) imply LSPs terminating at\n             this LSR.  Note that situations where LSPs are\n             terminated with incoming label equal to the string\n             containing a single octet 0x00 can be distinguished\n             from LSPs originating at this LSR because the\n             mplsXCOutSegmentIndex equals the string containing the\n             single octet 0x00.\n    \n             An entry can be created by a network administrator\n             or by an SNMP agent as instructed by an MPLS\n             signaling protocol.')
mplsXCIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsXCIndex.setDescription('Primary index for the conceptual row identifying a\n             group of cross-connect segments. The string\n             containing a single octet 0x00 is an invalid index.')
mplsXCInSegmentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 2), MplsIndexType())
if mibBuilder.loadTexts: mplsXCInSegmentIndex.setDescription("Incoming label index.\n             If this object is set to the string containing\n             a single octet 0x00, this indicates a special\n             case outlined in the table's description above.\n             In this case no corresponding mplsInSegmentEntry\n             shall exist.")
mplsXCOutSegmentIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 3), MplsIndexType())
if mibBuilder.loadTexts: mplsXCOutSegmentIndex.setDescription('Index of out-segment for LSPs not terminating on\n             this LSR if not set to the string containing the\n             single octet 0x00. If the segment identified by this\n             entry is terminating, then this object MUST be set to\n             the string containing a single octet 0x00 to indicate\n             that no corresponding mplsOutSegmentEntry shall\n             exist.')
mplsXCLspId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 4), MplsLSPID()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsXCLspId.setDescription('This value identifies the label switched path that\n             this cross-connect entry belongs to. This object\n             cannot be modified if mplsXCRowStatus is active(1)\n             except for this object.')
mplsXCLabelStackIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 5), MplsIndexType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsXCLabelStackIndex.setDescription('Primary index into mplsLabelStackTable identifying a\n             stack of labels to be pushed beneath the top label.\n             Note that the top label identified by the out-\n             segment ensures that all the components of a\n             multipoint-to-point connection have the same\n             outgoing label. A value of the string containing the\n             single octet 0x00 indicates that no labels are to\n             be stacked beneath the top label.\n             This object cannot be modified if mplsXCRowStatus is\n             active(1).')
mplsXCOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 6), MplsOwner()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsXCOwner.setDescription('Denotes the entity that created and is responsible\n             for managing this cross-connect.')
mplsXCRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsXCRowStatus.setDescription('For creating, modifying, and deleting this row.\n             When a row in this table has a row in the active(1)\n             state, no objects in this row except this object\n             and the mplsXCStorageType can be modified. ')
mplsXCStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 8), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsXCStorageType.setDescription("This variable indicates the storage type for this\n             object. The agent MUST ensure that the associated in\n             and out segments also have the same StorageType value\n             and are restored consistently upon system restart.\n             This value SHOULD be set to permanent(4) if created\n             as a result of a static LSP configuration.\n    \n             Conceptual rows having the value 'permanent'\n             need not allow write-access to any columnar\n             objects in the row.")
mplsXCAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3),)).clone('up')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsXCAdminStatus.setDescription('The desired operational status of this segment.')
mplsXCOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 10, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3), ("unknown", 4), ("dormant", 5), ("notPresent", 6), ("lowerLayerDown", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsXCOperStatus.setDescription('The actual operational status of this cross-\n             connect.')
mplsMaxLabelStackDepth = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 11), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsMaxLabelStackDepth.setDescription('The maximum stack depth supported by this LSR.')
mplsLabelStackIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 12), MplsIndexNextType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLabelStackIndexNext.setDescription('This object contains the next available value to\n             be used for mplsLabelStackIndex when creating entries\n             in the mplsLabelStackTable. The special string\n             containing the single octet 0x00\n             indicates that no more new entries can be created\n             in the relevant table.  Agents not allowing managers\n             to create entries in this table MUST set this value\n             to the string containing the single octet 0x00.')
mplsLabelStackTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13), )
if mibBuilder.loadTexts: mplsLabelStackTable.setDescription('This table specifies the label stack to be pushed\n             onto a packet, beneath the top label.  Entries into\n             this table are referred to from mplsXCTable.')
mplsLabelStackEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsLabelStackIndex"), (0, "MPLS-LSR-STD-MIB", "mplsLabelStackLabelIndex"))
if mibBuilder.loadTexts: mplsLabelStackEntry.setDescription('An entry in this table represents one label which is\n             to be pushed onto an outgoing packet, beneath the\n             top label.  An entry can be created by a network\n             administrator or by an SNMP agent as instructed by\n             an MPLS signaling protocol.')
mplsLabelStackIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 1), MplsIndexType())
if mibBuilder.loadTexts: mplsLabelStackIndex.setDescription('Primary index for this row identifying a stack of\n             labels to be pushed on an outgoing packet, beneath\n             the top label. An index containing the string with\n             a single octet 0x00 MUST not be used.')
mplsLabelStackLabelIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: mplsLabelStackLabelIndex.setDescription('Secondary index for this row identifying one label\n             of the stack.  Note that an entry with a smaller\n             mplsLabelStackLabelIndex would refer to a label\n             higher up the label stack and would be popped at a\n             downstream LSR before a label represented by a\n             higher mplsLabelStackLabelIndex at a downstream\n             LSR.')
mplsLabelStackLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 3), MplsLabel()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLabelStackLabel.setDescription('The label to pushed.')
mplsLabelStackLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 4), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLabelStackLabelPtr.setDescription('If the label for this segment cannot be represented\n             fully within the mplsLabelStackLabel object,\n             this object MUST point to the first accessible\n             column of a conceptual row in an external table containing\n             the label.  In this case, the mplsLabelStackLabel\n             object SHOULD be set to 0 and ignored. This object\n             MUST be set to zeroDotZero otherwise.')
mplsLabelStackRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLabelStackRowStatus.setDescription('For creating, modifying, and deleting this row.\n             When a row in this table has a row in the active(1)\n             state, no objects in this row except this object\n             and the mplsLabelStackStorageType can be modified.')
mplsLabelStackStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 13, 1, 6), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLabelStackStorageType.setDescription("This variable indicates the storage type for this\n             object. This object cannot be modified if\n             mplsLabelStackRowStatus is active(1).\n             No objects are required to be writable for\n             rows in this table with this object set to\n             permanent(4).\n    \n             The agent MUST ensure that all related entries\n             in this table retain the same value for this\n             object.  Agents MUST ensure that the storage type\n             for all entries related to a particular mplsXCEntry\n             retain the same value for this object as the\n             mplsXCEntry's StorageType.")
mplsInSegmentMapTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14), )
if mibBuilder.loadTexts: mplsInSegmentMapTable.setDescription('This table specifies the mapping from the\n             mplsInSegmentIndex to the corresponding\n             mplsInSegmentInterface and mplsInSegmentLabel\n             objects. The purpose of this table is to\n             provide the manager with an alternative\n             means by which to locate in-segments.')
mplsInSegmentMapEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsInSegmentMapInterface"), (0, "MPLS-LSR-STD-MIB", "mplsInSegmentMapLabel"), (0, "MPLS-LSR-STD-MIB", "mplsInSegmentMapLabelPtrIndex"))
if mibBuilder.loadTexts: mplsInSegmentMapEntry.setDescription("An entry in this table represents one interface\n             and incoming label pair.\n    \n             In cases where the label cannot fit into the\n             mplsInSegmentLabel object, the mplsInSegmentLabelPtr\n             will indicate this by being set to the first accessible\n             column in the appropriate extension table's row,\n             and the mplsInSegmentLabel SHOULD be set to 0.\n             In all other cases when the label is\n             represented within the mplsInSegmentLabel object, the\n             mplsInSegmentLabelPtr MUST be 0.0.\n    \n             Implementors need to be aware that if the value of\n             the mplsInSegmentMapLabelPtrIndex (an OID) has more\n             that 111 sub-identifiers, then OIDs of column\n             instances in this table will have more than 128\n             sub-identifiers and cannot be accessed using SNMPv1,\n             SNMPv2c, or SNMPv3.")
mplsInSegmentMapInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14, 1, 1), InterfaceIndexOrZero())
if mibBuilder.loadTexts: mplsInSegmentMapInterface.setDescription('This index contains the same value as the\n             mplsInSegmentIndex in the mplsInSegmentTable.')
mplsInSegmentMapLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14, 1, 2), MplsLabel())
if mibBuilder.loadTexts: mplsInSegmentMapLabel.setDescription('This index contains the same value as the\n             mplsInSegmentLabel in the mplsInSegmentTable.')
mplsInSegmentMapLabelPtrIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14, 1, 3), RowPointer())
if mibBuilder.loadTexts: mplsInSegmentMapLabelPtrIndex.setDescription('This index contains the same value as the\n             mplsInSegmentLabelPtr.\n    \n             If the label for the InSegment cannot be represented\n             fully within the mplsInSegmentLabel object,\n             this index MUST point to the first accessible\n             column of a conceptual row in an external table containing\n             the label.  In this case, the mplsInSegmentTopLabel\n             object SHOULD be set to 0 and ignored. This object MUST\n             be set to zeroDotZero otherwise.')
mplsInSegmentMapIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 14, 1, 4), MplsIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsInSegmentMapIndex.setDescription('The mplsInSegmentIndex that corresponds\n             to the mplsInSegmentInterface and\n             mplsInSegmentLabel, or the mplsInSegmentInterface\n             and mplsInSegmentLabelPtr, if applicable.\n             The string containing the single octet 0x00\n             MUST not be returned.')
mplsXCNotificationsEnable = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 2, 1, 15), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mplsXCNotificationsEnable.setDescription('If this object is set to true(1), then it enables\n             the emission of mplsXCUp and mplsXCDown\n             notifications; otherwise these notifications are not\n             emitted.')
mplsXCUp = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 2, 0, 1)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsXCOperStatus"), ("MPLS-LSR-STD-MIB", "mplsXCOperStatus"),))
if mibBuilder.loadTexts: mplsXCUp.setDescription('This notification is generated when the\n             mplsXCOperStatus object for one or more contiguous\n             entries in mplsXCTable are about to enter the up(1)\n             state from some other state. The included values of\n             mplsXCOperStatus MUST both be set equal to this\n             new state (i.e: up(1)).  The two instances of\n             mplsXCOperStatus in this notification indicate the range\n             of indexes that are affected.  Note that all the indexes\n             of the two ends of the range can be derived from the\n             instance identifiers of these two objects.  For\n             cases where a contiguous range of cross-connects\n             have transitioned into the up(1) state at roughly\n             the same time, the device SHOULD issue a single\n             notification for each range of contiguous indexes in\n             an effort to minimize the emission of a large number\n             of notifications.  If a notification has to be\n             issued for just a single cross-connect entry, then\n             the instance identifier (and values) of the two\n             mplsXCOperStatus objects MUST be the identical.')
mplsXCDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 2, 0, 2)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsXCOperStatus"), ("MPLS-LSR-STD-MIB", "mplsXCOperStatus"),))
if mibBuilder.loadTexts: mplsXCDown.setDescription('This notification is generated when the\n             mplsXCOperStatus object for one or more contiguous\n             entries in mplsXCTable are about to enter the\n             down(2) state from some other state. The included values\n             of mplsXCOperStatus MUST both be set equal to this\n             down(2) state.  The two instances of mplsXCOperStatus\n             in this notification indicate the range of indexes\n             that are affected.  Note that all the indexes of the\n             two ends of the range can be derived from the\n             instance identifiers of these two objects.  For\n             cases where a contiguous range of cross-connects\n             have transitioned into the down(2) state at roughly\n             the same time, the device SHOULD issue a single\n             notification for each range of contiguous indexes in\n             an effort to minimize the emission of a large number\n             of notifications.  If a notification has to be\n             issued for just a single cross-connect entry, then\n             the instance identifier (and values) of the two\n             mplsXCOperStatus objects MUST be identical.')
mplsLsrGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1))
mplsLsrCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 2))
mplsLsrModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 2, 1)).setObjects(*(("IF-MIB", "ifGeneralInformationGroup"), ("IF-MIB", "ifCounterDiscontinuityGroup"), ("MPLS-LSR-STD-MIB", "mplsInterfaceGroup"), ("MPLS-LSR-STD-MIB", "mplsInSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsXCGroup"), ("MPLS-LSR-STD-MIB", "mplsPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsLabelStackGroup"), ("MPLS-LSR-STD-MIB", "mplsHCInSegmentPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsHCOutSegmentPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsLsrNotificationGroup"),))
if mibBuilder.loadTexts: mplsLsrModuleFullCompliance.setDescription('Compliance statement for agents that provide full\n                      support for MPLS-LSR-STD-MIB. Such devices can\n                      then be monitored and also be configured using\n                      this MIB module.')
mplsLsrModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 2, 2)).setObjects(*(("IF-MIB", "ifGeneralInformationGroup"), ("IF-MIB", "ifCounterDiscontinuityGroup"), ("MPLS-LSR-STD-MIB", "mplsInterfaceGroup"), ("MPLS-LSR-STD-MIB", "mplsInSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsXCGroup"), ("MPLS-LSR-STD-MIB", "mplsPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsLabelStackGroup"), ("MPLS-LSR-STD-MIB", "mplsHCInSegmentPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsHCOutSegmentPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsLsrNotificationGroup"),))
if mibBuilder.loadTexts: mplsLsrModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only\n                      provide read-only support for MPLS-LSR-STD-MIB. Such\n                      devices can then be monitored but cannot be configured\n                      using this MIB module.\n                     ')
mplsInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 1)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsInterfaceLabelMinIn"), ("MPLS-LSR-STD-MIB", "mplsInterfaceLabelMaxIn"), ("MPLS-LSR-STD-MIB", "mplsInterfaceLabelMinOut"), ("MPLS-LSR-STD-MIB", "mplsInterfaceLabelMaxOut"), ("MPLS-LSR-STD-MIB", "mplsInterfaceTotalBandwidth"), ("MPLS-LSR-STD-MIB", "mplsInterfaceAvailableBandwidth"), ("MPLS-LSR-STD-MIB", "mplsInterfaceLabelParticipationType"),))
if mibBuilder.loadTexts: mplsInterfaceGroup.setDescription('Collection of objects needed for MPLS interface\n                and interface performance information.')
mplsInSegmentGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 2)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsInSegmentIndexNext"), ("MPLS-LSR-STD-MIB", "mplsInSegmentInterface"), ("MPLS-LSR-STD-MIB", "mplsInSegmentLabel"), ("MPLS-LSR-STD-MIB", "mplsInSegmentLabelPtr"), ("MPLS-LSR-STD-MIB", "mplsInSegmentNPop"), ("MPLS-LSR-STD-MIB", "mplsInSegmentAddrFamily"), ("MPLS-LSR-STD-MIB", "mplsInSegmentXCIndex"), ("MPLS-LSR-STD-MIB", "mplsInSegmentOwner"), ("MPLS-LSR-STD-MIB", "mplsInSegmentRowStatus"), ("MPLS-LSR-STD-MIB", "mplsInSegmentStorageType"), ("MPLS-LSR-STD-MIB", "mplsInSegmentTrafficParamPtr"), ("MPLS-LSR-STD-MIB", "mplsInSegmentMapIndex"),))
if mibBuilder.loadTexts: mplsInSegmentGroup.setDescription('Collection of objects needed to implement an in-\n            segment.')
mplsOutSegmentGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 3)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsOutSegmentIndexNext"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentInterface"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPushTopLabel"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentTopLabel"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentTopLabelPtr"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentNextHopAddrType"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentNextHopAddr"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentXCIndex"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentOwner"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfOctets"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfDiscards"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfErrors"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentRowStatus"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentStorageType"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentTrafficParamPtr"),))
if mibBuilder.loadTexts: mplsOutSegmentGroup.setDescription('Collection of objects needed to implement an out-\n            segment.')
mplsXCGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 4)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsXCIndexNext"), ("MPLS-LSR-STD-MIB", "mplsXCLspId"), ("MPLS-LSR-STD-MIB", "mplsXCLabelStackIndex"), ("MPLS-LSR-STD-MIB", "mplsXCOwner"), ("MPLS-LSR-STD-MIB", "mplsXCStorageType"), ("MPLS-LSR-STD-MIB", "mplsXCAdminStatus"), ("MPLS-LSR-STD-MIB", "mplsXCOperStatus"), ("MPLS-LSR-STD-MIB", "mplsXCRowStatus"), ("MPLS-LSR-STD-MIB", "mplsXCNotificationsEnable"),))
if mibBuilder.loadTexts: mplsXCGroup.setDescription('Collection of objects needed to implement a\n                cross-connect entry.')
mplsPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 5)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsInSegmentPerfOctets"), ("MPLS-LSR-STD-MIB", "mplsInSegmentPerfPackets"), ("MPLS-LSR-STD-MIB", "mplsInSegmentPerfErrors"), ("MPLS-LSR-STD-MIB", "mplsInSegmentPerfDiscards"), ("MPLS-LSR-STD-MIB", "mplsInSegmentPerfDiscontinuityTime"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfOctets"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfPackets"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfDiscards"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfDiscontinuityTime"), ("MPLS-LSR-STD-MIB", "mplsInterfacePerfInLabelsInUse"), ("MPLS-LSR-STD-MIB", "mplsInterfacePerfInLabelLookupFailures"), ("MPLS-LSR-STD-MIB", "mplsInterfacePerfOutFragmentedPkts"), ("MPLS-LSR-STD-MIB", "mplsInterfacePerfOutLabelsInUse"),))
if mibBuilder.loadTexts: mplsPerfGroup.setDescription('Collection of objects providing performance\n             information\n             about an LSR.')
mplsHCInSegmentPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 6)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsInSegmentPerfHCOctets"),))
if mibBuilder.loadTexts: mplsHCInSegmentPerfGroup.setDescription('Object(s) providing performance information\n             specific to out-segments for which the object\n             mplsInterfaceInOctets wraps around too quickly.')
mplsHCOutSegmentPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 7)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsOutSegmentPerfHCOctets"),))
if mibBuilder.loadTexts: mplsHCOutSegmentPerfGroup.setDescription('Object(s) providing performance information\n             specific to out-segments for which the object\n             mplsInterfaceOutOctets wraps around too\n             quickly.')
mplsLabelStackGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 8)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsLabelStackLabel"), ("MPLS-LSR-STD-MIB", "mplsLabelStackLabelPtr"), ("MPLS-LSR-STD-MIB", "mplsLabelStackRowStatus"), ("MPLS-LSR-STD-MIB", "mplsLabelStackStorageType"), ("MPLS-LSR-STD-MIB", "mplsMaxLabelStackDepth"), ("MPLS-LSR-STD-MIB", "mplsLabelStackIndexNext"),))
if mibBuilder.loadTexts: mplsLabelStackGroup.setDescription('Objects needed to support label stacking.')
mplsLsrNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 166, 2, 2, 1, 9)).setObjects(*(("MPLS-LSR-STD-MIB", "mplsXCUp"), ("MPLS-LSR-STD-MIB", "mplsXCDown"),))
if mibBuilder.loadTexts: mplsLsrNotificationGroup.setDescription('Set of notifications implemented in this\n                module.')
mibBuilder.exportSymbols("MPLS-LSR-STD-MIB", mplsLabelStackLabelPtr=mplsLabelStackLabelPtr, mplsInSegmentPerfDiscards=mplsInSegmentPerfDiscards, mplsXCOwner=mplsXCOwner, mplsOutSegmentEntry=mplsOutSegmentEntry, mplsOutSegmentPerfDiscards=mplsOutSegmentPerfDiscards, mplsInterfacePerfOutLabelsInUse=mplsInterfacePerfOutLabelsInUse, mplsInSegmentStorageType=mplsInSegmentStorageType, mplsXCRowStatus=mplsXCRowStatus, mplsInSegmentMapLabel=mplsInSegmentMapLabel, mplsXCInSegmentIndex=mplsXCInSegmentIndex, mplsLabelStackRowStatus=mplsLabelStackRowStatus, mplsOutSegmentRowStatus=mplsOutSegmentRowStatus, mplsOutSegmentIndex=mplsOutSegmentIndex, mplsXCUp=mplsXCUp, mplsOutSegmentOwner=mplsOutSegmentOwner, mplsOutSegmentTopLabel=mplsOutSegmentTopLabel, mplsInSegmentXCIndex=mplsInSegmentXCIndex, mplsInSegmentPerfEntry=mplsInSegmentPerfEntry, mplsLsrModuleReadOnlyCompliance=mplsLsrModuleReadOnlyCompliance, mplsInSegmentPerfErrors=mplsInSegmentPerfErrors, mplsXCEntry=mplsXCEntry, mplsXCDown=mplsXCDown, mplsLabelStackLabel=mplsLabelStackLabel, mplsOutSegmentTable=mplsOutSegmentTable, mplsXCLabelStackIndex=mplsXCLabelStackIndex, mplsInterfacePerfEntry=mplsInterfacePerfEntry, mplsInterfaceEntry=mplsInterfaceEntry, mplsXCTable=mplsXCTable, mplsLabelStackGroup=mplsLabelStackGroup, mplsInSegmentTable=mplsInSegmentTable, mplsXCLspId=mplsXCLspId, mplsLsrConformance=mplsLsrConformance, mplsInterfaceLabelMinOut=mplsInterfaceLabelMinOut, mplsOutSegmentPerfPackets=mplsOutSegmentPerfPackets, mplsInterfacePerfInLabelsInUse=mplsInterfacePerfInLabelsInUse, mplsInterfaceTable=mplsInterfaceTable, mplsXCOutSegmentIndex=mplsXCOutSegmentIndex, mplsInSegmentMapEntry=mplsInSegmentMapEntry, mplsLsrStdMIB=mplsLsrStdMIB, mplsInSegmentPerfHCOctets=mplsInSegmentPerfHCOctets, mplsOutSegmentPushTopLabel=mplsOutSegmentPushTopLabel, mplsLsrCompliances=mplsLsrCompliances, mplsOutSegmentPerfOctets=mplsOutSegmentPerfOctets, mplsInSegmentMapLabelPtrIndex=mplsInSegmentMapLabelPtrIndex, mplsInterfaceTotalBandwidth=mplsInterfaceTotalBandwidth, mplsXCGroup=mplsXCGroup, mplsLabelStackEntry=mplsLabelStackEntry, mplsOutSegmentNextHopAddrType=mplsOutSegmentNextHopAddrType, mplsOutSegmentTopLabelPtr=mplsOutSegmentTopLabelPtr, mplsInSegmentIndexNext=mplsInSegmentIndexNext, mplsInterfacePerfOutFragmentedPkts=mplsInterfacePerfOutFragmentedPkts, mplsLsrObjects=mplsLsrObjects, mplsOutSegmentNextHopAddr=mplsOutSegmentNextHopAddr, mplsPerfGroup=mplsPerfGroup, mplsHCOutSegmentPerfGroup=mplsHCOutSegmentPerfGroup, mplsInSegmentNPop=mplsInSegmentNPop, mplsLabelStackIndexNext=mplsLabelStackIndexNext, mplsInSegmentRowStatus=mplsInSegmentRowStatus, mplsLsrModuleFullCompliance=mplsLsrModuleFullCompliance, mplsInterfaceIndex=mplsInterfaceIndex, mplsInSegmentTrafficParamPtr=mplsInSegmentTrafficParamPtr, mplsInSegmentGroup=mplsInSegmentGroup, mplsInSegmentIndex=mplsInSegmentIndex, mplsOutSegmentPerfErrors=mplsOutSegmentPerfErrors, mplsLabelStackTable=mplsLabelStackTable, mplsOutSegmentInterface=mplsOutSegmentInterface, mplsInSegmentPerfTable=mplsInSegmentPerfTable, MplsIndexNextType=MplsIndexNextType, mplsOutSegmentPerfTable=mplsOutSegmentPerfTable, mplsInterfaceLabelParticipationType=mplsInterfaceLabelParticipationType, mplsOutSegmentStorageType=mplsOutSegmentStorageType, mplsInSegmentMapIndex=mplsInSegmentMapIndex, mplsXCIndexNext=mplsXCIndexNext, mplsOutSegmentXCIndex=mplsOutSegmentXCIndex, mplsInSegmentLabel=mplsInSegmentLabel, mplsInterfaceLabelMaxIn=mplsInterfaceLabelMaxIn, mplsInSegmentPerfPackets=mplsInSegmentPerfPackets, mplsOutSegmentTrafficParamPtr=mplsOutSegmentTrafficParamPtr, mplsXCOperStatus=mplsXCOperStatus, mplsInSegmentLabelPtr=mplsInSegmentLabelPtr, PYSNMP_MODULE_ID=mplsLsrStdMIB, mplsOutSegmentPerfEntry=mplsOutSegmentPerfEntry, mplsXCNotificationsEnable=mplsXCNotificationsEnable, mplsLsrNotificationGroup=mplsLsrNotificationGroup, mplsInSegmentMapTable=mplsInSegmentMapTable, mplsInterfaceLabelMinIn=mplsInterfaceLabelMinIn, mplsInSegmentMapInterface=mplsInSegmentMapInterface, mplsInterfaceGroup=mplsInterfaceGroup, mplsLabelStackIndex=mplsLabelStackIndex, mplsInSegmentInterface=mplsInSegmentInterface, mplsLabelStackLabelIndex=mplsLabelStackLabelIndex, mplsInterfacePerfTable=mplsInterfacePerfTable, mplsInSegmentPerfOctets=mplsInSegmentPerfOctets, mplsInSegmentPerfDiscontinuityTime=mplsInSegmentPerfDiscontinuityTime, mplsLabelStackStorageType=mplsLabelStackStorageType, mplsXCIndex=mplsXCIndex, mplsInterfaceLabelMaxOut=mplsInterfaceLabelMaxOut, mplsInSegmentAddrFamily=mplsInSegmentAddrFamily, mplsXCAdminStatus=mplsXCAdminStatus, mplsLsrGroups=mplsLsrGroups, mplsInterfacePerfInLabelLookupFailures=mplsInterfacePerfInLabelLookupFailures, mplsOutSegmentIndexNext=mplsOutSegmentIndexNext, mplsOutSegmentGroup=mplsOutSegmentGroup, mplsXCStorageType=mplsXCStorageType, mplsHCInSegmentPerfGroup=mplsHCInSegmentPerfGroup, mplsInSegmentEntry=mplsInSegmentEntry, mplsLsrNotifications=mplsLsrNotifications, MplsIndexType=MplsIndexType, mplsOutSegmentPerfHCOctets=mplsOutSegmentPerfHCOctets, mplsInSegmentOwner=mplsInSegmentOwner, mplsOutSegmentPerfDiscontinuityTime=mplsOutSegmentPerfDiscontinuityTime, mplsInterfaceAvailableBandwidth=mplsInterfaceAvailableBandwidth, mplsMaxLabelStackDepth=mplsMaxLabelStackDepth)



#
# PySNMP MIB module UCD-SNMP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/UCD-SNMP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:22 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsUnion")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Gauge32, MibIdentifier, Opaque, Integer32, NotificationType, Bits, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Counter64, enterprises, ObjectIdentity, iso, IpAddress, ModuleIdentity, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "MibIdentifier", "Opaque", "Integer32", "NotificationType", "Bits", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Counter64", "enterprises", "ObjectIdentity", "iso", "IpAddress", "ModuleIdentity", "Unsigned32")
( TextualConvention, DisplayString, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TruthValue")
ucdavis = ModuleIdentity((1, 3, 6, 1, 4, 1, 2021)).setRevisions(("2011-05-14 00:00", "2009-01-19 00:00", "2006-11-22 00:00", "2004-04-07 00:00", "2002-09-05 00:00", "2001-09-20 00:00", "2001-01-17 00:00", "1999-12-09 00:00",))
if mibBuilder.loadTexts: ucdavis.setLastUpdated('200901190000Z')
if mibBuilder.loadTexts: ucdavis.setOrganization('University of California, Davis')
if mibBuilder.loadTexts: ucdavis.setContactInfo('This mib is no longer being maintained by the University of\n\t California and is now in life-support-mode and being\n\t maintained by the net-snmp project.  The best place to write\n\t for public questions about the net-snmp-coders mailing list\n\t at net-snmp-coders@lists.sourceforge.net.\n\n         postal:   Wes Hardaker\n                   P.O. Box 382\n                   Davis CA  95617\n\n         email:    net-snmp-coders@lists.sourceforge.net\n        ')
if mibBuilder.loadTexts: ucdavis.setDescription('This file defines the private UCD SNMP MIB extensions.')
ucdInternal = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 12))
ucdExperimental = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 13))
ucdSnmpAgent = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250))
hpux9 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 1))
sunos4 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 2))
solaris = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 3))
osf = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 4))
ultrix = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 5))
hpux10 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 6))
netbsd1 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 7))
freebsd = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 8))
irix = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 9))
linux = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 10))
bsdi = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 11))
openbsd = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 12))
win32 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 13))
hpux11 = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 14))
aix = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 15))
macosx = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 16))
dragonfly = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 17))
unknown = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 250, 255))
class Float(Opaque, TextualConvention):
    subtypeSpec = Opaque.subtypeSpec+ValueSizeConstraint(7,7)
    fixedLength = 7

class UCDErrorFlag(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1,))
    namedValues = NamedValues(("noError", 0), ("error", 1),)

class UCDErrorFix(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1,))
    namedValues = NamedValues(("noError", 0), ("runFix", 1),)

prTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 2), )
if mibBuilder.loadTexts: prTable.setDescription("A table containing information on running\n\t programs/daemons configured for monitoring in the\n\t snmpd.conf file of the agent.  Processes violating the\n\t number of running processes required by the agent's\n\t configuration file are flagged with numerical and\n\t textual errors.")
prEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 2, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "prIndex"))
if mibBuilder.loadTexts: prEntry.setDescription('An entry containing a process and its statistics.')
prIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: prIndex.setDescription('Reference Index for each observed process.')
prNames = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prNames.setDescription("The process name we're counting/checking on.")
prMin = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prMin.setDescription('The minimum number of processes that should be\n\t running.  An error flag is generated if the number of\n\t running processes is < the minimum.')
prMax = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prMax.setDescription('The maximum number of processes that should be\n\t running.  An error flag is generated if the number of\n\t running processes is > the maximum.')
prCount = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prCount.setDescription('The number of current processes running with the name\n\t in question.')
prErrorFlag = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prErrorFlag.setDescription('A Error flag to indicate trouble with a process.  It\n\t goes to 1 if there is an error, 0 if no error.')
prErrMessage = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prErrMessage.setDescription('An error message describing the problem (if one exists).')
prErrFix = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 102), UCDErrorFix()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: prErrFix.setDescription('Setting this to one will try to fix the problem if\n\t the agent has been configured with a script to call\n\t to attempt to fix problems automatically using remote\n\t snmp operations.')
prErrFixCmd = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 2, 1, 103), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: prErrFixCmd.setDescription('The command that gets run when the prErrFix column is \n\t set to 1.')
extTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 8), )
if mibBuilder.loadTexts: extTable.setDescription("A table of extensible commands returning output and\n\t result codes.  These commands are configured via the\n\t agent's snmpd.conf file.")
extEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 8, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "extIndex"))
if mibBuilder.loadTexts: extEntry.setDescription('An entry containing an extensible script/program and its output.')
extIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: extIndex.setDescription('Reference Index for extensible scripts.  Simply an\n\t integer row number.')
extNames = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: extNames.setDescription('A Short, one name description of the extensible command.')
extCommand = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: extCommand.setDescription('The command line to be executed.')
extResult = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 100), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: extResult.setDescription('The result code (exit status) from the executed command.')
extOutput = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: extOutput.setDescription('The first line of output of the executed command.')
extErrFix = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 102), UCDErrorFix()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: extErrFix.setDescription('Setting this to one will try to fix the problem if\n\t the agent has been configured with a script to call\n\t to attempt to fix problems automatically using remote\n\t snmp operations.')
extErrFixCmd = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 8, 1, 103), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: extErrFixCmd.setDescription('The command that gets run when the extErrFix column is \n\t set to 1.')
memory = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 4))
memIndex = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: memIndex.setDescription('Bogus Index.  This should always return the integer 0.')
memErrorName = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: memErrorName.setDescription("Bogus Name. This should always return the string 'swap'.")
memTotalSwap = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 3), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memTotalSwap.setDescription('The total amount of swap space configured for this host.')
memAvailSwap = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 4), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memAvailSwap.setDescription('The amount of swap space currently unused or available.')
memTotalReal = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 5), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memTotalReal.setDescription('The total amount of real/physical memory installed\n         on this host.')
memAvailReal = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 6), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memAvailReal.setDescription('The amount of real/physical memory currently unused\n         or available.')
memTotalSwapTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 7), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memTotalSwapTXT.setDescription('The total amount of swap space or virtual memory allocated\n         for text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of swap space or virtual memory.')
memAvailSwapTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 8), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memAvailSwapTXT.setDescription("The amount of swap space or virtual memory currently\n         being used by text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of swap space or virtual memory.\n\n         Note that (despite the name), this value reports the\n         amount used, rather than the amount free or available\n         for use.  For clarity, this object is being deprecated\n         in favour of 'memUsedSwapTXT(16).")
memTotalRealTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 9), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memTotalRealTXT.setDescription('The total amount of real/physical memory allocated\n         for text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of physical memory.')
memAvailRealTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 10), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memAvailRealTXT.setDescription("The amount of real/physical memory currently being\n         used by text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of physical memory.\n\n         Note that (despite the name), this value reports the\n         amount used, rather than the amount free or available\n         for use.  For clarity, this object is being deprecated\n         in favour of 'memUsedRealTXT(17).")
memTotalFree = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 11), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memTotalFree.setDescription('The total amount of memory free or available for use on\n         this host.  This value typically covers both real memory\n         and swap space or virtual memory.')
memMinimumSwap = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 12), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memMinimumSwap.setDescription("The minimum amount of swap space expected to be kept\n         free or available during normal operation of this host.\n\n         If this value (as reported by 'memAvailSwap(4)') falls\n         below the specified level, then 'memSwapError(100)' will\n         be set to 1 and an error message made available via\n         'memSwapErrorMsg(101)'.")
memShared = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 13), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memShared.setDescription('The total amount of real or virtual memory currently\n         allocated for use as shared memory.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not explicitly identify\n         memory as specifically reserved for this purpose.')
memBuffer = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 14), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memBuffer.setDescription('The total amount of real or virtual memory currently\n         allocated for use as memory buffers.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not explicitly identify\n         memory as specifically reserved for this purpose.')
memCached = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 15), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memCached.setDescription('The total amount of real or virtual memory currently\n         allocated for use as cached memory.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not explicitly identify\n         memory as specifically reserved for this purpose.')
memUsedSwapTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 16), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memUsedSwapTXT.setDescription('The amount of swap space or virtual memory currently\n         being used by text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of swap space or virtual memory.')
memUsedRealTXT = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 17), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: memUsedRealTXT.setDescription('The amount of real/physical memory currently being\n         used by text pages on this host.\n\n         This object will not be implemented on hosts where the\n         underlying operating system does not distinguish text\n         pages from other uses of physical memory.')
memSwapError = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: memSwapError.setDescription("Indicates whether the amount of available swap space\n         (as reported by 'memAvailSwap(4)'), is less than the\n         desired minimum (specified by 'memMinimumSwap(12)').")
memSwapErrorMsg = MibScalar((1, 3, 6, 1, 4, 1, 2021, 4, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: memSwapErrorMsg.setDescription("Describes whether the amount of available swap space\n         (as reported by 'memAvailSwap(4)'), is less than the\n         desired minimum (specified by 'memMinimumSwap(12)').")
dskTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 9), )
if mibBuilder.loadTexts: dskTable.setDescription('Disk watching information.  Partions to be watched\n\t are configured by the snmpd.conf file of the agent.')
dskEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 9, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "dskIndex"))
if mibBuilder.loadTexts: dskEntry.setDescription('An entry containing a disk and its statistics.')
dskIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskIndex.setDescription('Integer reference number (row number) for the disk mib.')
dskPath = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskPath.setDescription('Path where the disk is mounted.')
dskDevice = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskDevice.setDescription('Path of the device for the partition')
dskMinimum = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskMinimum.setDescription("Minimum space required on the disk (in kBytes) before the\n         errors are triggered.  Either this or dskMinPercent is\n         configured via the agent's snmpd.conf file.")
dskMinPercent = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskMinPercent.setDescription("Percentage of minimum space required on the disk before the\n         errors are triggered.  Either this or dskMinimum is\n         configured via the agent's snmpd.conf file.")
dskTotal = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskTotal.setDescription('Total size of the disk/partion (kBytes).\n\t For large disks (>2Tb), this value will\n\t latch at INT32_MAX (2147483647).')
dskAvail = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskAvail.setDescription('Available space on the disk.\n\t For large lightly-used disks (>2Tb), this\n\t value will latch at INT32_MAX (2147483647).')
dskUsed = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskUsed.setDescription('Used space on the disk.\n\t For large heavily-used disks (>2Tb), this\n\t value will latch at INT32_MAX (2147483647).')
dskPercent = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 9), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskPercent.setDescription('Percentage of space used on disk')
dskPercentNode = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 10), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskPercentNode.setDescription('Percentage of inodes used on disk')
dskTotalLow = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 11), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskTotalLow.setDescription('Total size of the disk/partion (kBytes).\n\tTogether with dskTotalHigh composes 64-bit number.')
dskTotalHigh = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 12), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskTotalHigh.setDescription('Total size of the disk/partion (kBytes).\n\tTogether with dskTotalLow composes 64-bit number.')
dskAvailLow = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 13), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskAvailLow.setDescription('Available space on the disk (kBytes).\n\tTogether with dskAvailHigh composes 64-bit number.')
dskAvailHigh = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 14), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskAvailHigh.setDescription('Available space on the disk (kBytes).\n\tTogether with dskAvailLow composes 64-bit number.')
dskUsedLow = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 15), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskUsedLow.setDescription('Used space on the disk (kBytes).\n\tTogether with dskUsedHigh composes 64-bit number.')
dskUsedHigh = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 16), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskUsedHigh.setDescription('Used space on the disk (kBytes).\n\tTogether with dskUsedLow composes 64-bit number.')
dskErrorFlag = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskErrorFlag.setDescription('Error flag signaling that the disk or partition is under\n\t the minimum required space configured for it.')
dskErrorMsg = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 9, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dskErrorMsg.setDescription('A text description providing a warning and the space left\n\t on the disk.')
laTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 10), )
if mibBuilder.loadTexts: laTable.setDescription('Load average information.')
laEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 10, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "laIndex"))
if mibBuilder.loadTexts: laEntry.setDescription('An entry containing a load average and its values.')
laIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3))).setMaxAccess("readonly")
if mibBuilder.loadTexts: laIndex.setDescription('reference index/row number for each observed loadave.')
laNames = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laNames.setDescription("The list of loadave names we're watching.")
laLoad = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laLoad.setDescription('The 1,5 and 15 minute load averages (one per row).')
laConfig = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 4), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: laConfig.setDescription('The watch point for load-averages to signal an\n\t error.  If the load averages rises above this value,\n\t the laErrorFlag below is set.')
laLoadInt = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laLoadInt.setDescription('The 1,5 and 15 minute load averages as an integer.\n\t This is computed by taking the floating point\n\t loadaverage value and multiplying by 100, then\n\t converting the value to an integer.')
laLoadFloat = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 6), Float()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laLoadFloat.setDescription('The 1,5 and 15 minute load averages as an opaquely\n\t wrapped floating point number.')
laErrorFlag = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laErrorFlag.setDescription('A Error flag to indicate the load-average has crossed\n\t its threshold value defined in the snmpd.conf file.\n\t It is set to 1 if the threshold is crossed, 0 otherwise.')
laErrMessage = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 10, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: laErrMessage.setDescription('An error message describing the load-average and its\n\t surpased watch-point value.')
version = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 100))
versionIndex = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionIndex.setDescription('Index to mib (always 0)')
versionTag = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionTag.setDescription('CVS tag keyword')
versionDate = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionDate.setDescription('Date string from RCS keyword')
versionCDate = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionCDate.setDescription('Date string from ctime() ')
versionIdent = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 5), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionIdent.setDescription('Id string from RCS keyword')
versionConfigureOptions = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 6), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: versionConfigureOptions.setDescription('Options passed to the configure script when this agent was built.')
versionClearCache = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 10), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: versionClearCache.setDescription('Set to 1 to clear the exec cache, if enabled')
versionUpdateConfig = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 11), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: versionUpdateConfig.setDescription('Set to 1 to read-read the config file(s).')
versionRestartAgent = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 12), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: versionRestartAgent.setDescription('Set to 1 to restart the agent.')
versionSavePersistentData = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 13), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: versionSavePersistentData.setDescription("Set to 1 to force the agent to save it's persistent data immediately.")
versionDoDebugging = MibScalar((1, 3, 6, 1, 4, 1, 2021, 100, 20), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: versionDoDebugging.setDescription('Set to 1 to turn debugging statements on in the agent or 0\n\t to turn it off.')
snmperrs = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 101))
snmperrIndex = MibScalar((1, 3, 6, 1, 4, 1, 2021, 101, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: snmperrIndex.setDescription('Bogus Index for snmperrs (always 0).')
snmperrNames = MibScalar((1, 3, 6, 1, 4, 1, 2021, 101, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: snmperrNames.setDescription('snmp')
snmperrErrorFlag = MibScalar((1, 3, 6, 1, 4, 1, 2021, 101, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: snmperrErrorFlag.setDescription('A Error flag to indicate trouble with the agent.  It\n\t goes to 1 if there is an error, 0 if no error.')
snmperrErrMessage = MibScalar((1, 3, 6, 1, 4, 1, 2021, 101, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: snmperrErrMessage.setDescription('An error message describing the problem (if one exists).')
mrTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 102), )
if mibBuilder.loadTexts: mrTable.setDescription("A table displaying all the oid's registered by mib modules in\n\t the agent.  Since the agent is modular in nature, this lists\n\t each module's OID it is responsible for and the name of the module")
mrEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 102, 1), ).setIndexNames((1, "UCD-SNMP-MIB", "mrIndex"))
if mibBuilder.loadTexts: mrEntry.setDescription('An entry containing a registered mib oid.')
mrIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 102, 1, 1), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mrIndex.setDescription('The registry slot of a mibmodule.')
mrModuleName = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 102, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mrModuleName.setDescription('The module name that registered this OID.')
systemStats = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 11))
ssIndex = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssIndex.setDescription('Bogus Index.  This should always return the integer 1.')
ssErrorName = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssErrorName.setDescription("Bogus Name. This should always return the string 'systemStats'.")
ssSwapIn = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 3), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssSwapIn.setDescription('The average amount of memory swapped in from disk,\n         calculated over the last minute.')
ssSwapOut = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 4), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssSwapOut.setDescription('The average amount of memory swapped out to disk,\n         calculated over the last minute.')
ssIOSent = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 5), Integer32()).setUnits('blocks/s').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssIOSent.setDescription("The average amount of data written to disk or other\n         block device, calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssIORawSent(57)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssIOReceive = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 6), Integer32()).setUnits('blocks/s').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssIOReceive.setDescription("The average amount of data read from disk or other\n         block device, calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssIORawReceived(58)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssSysInterrupts = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 7), Integer32()).setUnits('interrupts/s').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssSysInterrupts.setDescription("The average rate of interrupts processed (including\n         the clock) calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssRawInterrupts(59)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssSysContext = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 8), Integer32()).setUnits('switches/s').setMaxAccess("readonly")
if mibBuilder.loadTexts: ssSysContext.setDescription("The average rate of context switches,\n         calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssRawContext(60)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssCpuUser = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 9), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuUser.setDescription("The percentage of CPU time spent processing\n         user-level code, calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssCpuRawUser(50)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssCpuSystem = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 10), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuSystem.setDescription("The percentage of CPU time spent processing\n         system-level code, calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssCpuRawSystem(52)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssCpuIdle = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 11), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuIdle.setDescription("The percentage of processor time spent idle,\n         calculated over the last minute.\n       \n\t This object has been deprecated in favour of\n         'ssCpuRawIdle(53)', which can be used to calculate\n         the same metric, but over any desired time period.")
ssCpuRawUser = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 50), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawUser.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing user-level code.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawNice = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 51), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawNice.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing reduced-priority code.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawSystem = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 52), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawSystem.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing system-level code.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).\n\n         This object may sometimes be implemented as the\n         combination of the 'ssCpuRawWait(54)' and\n         'ssCpuRawKernel(55)' counters, so care must be\n         taken when summing the overall raw counters.")
ssCpuRawIdle = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 53), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawIdle.setDescription("The number of 'ticks' (typically 1/100s) spent\n         idle.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawWait = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 54), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawWait.setDescription("The number of 'ticks' (typically 1/100s) spent\n         waiting for IO.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.  This time may also be\n         included within the 'ssCpuRawSystem(52)' counter.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawKernel = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 55), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawKernel.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing kernel-level code.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.  This time may also be\n         included within the 'ssCpuRawSystem(52)' counter.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawInterrupt = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 56), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawInterrupt.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing hardware interrupts.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssIORawSent = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 57), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssIORawSent.setDescription('Number of blocks sent to a block device')
ssIORawReceived = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 58), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssIORawReceived.setDescription('Number of blocks received from a block device')
ssRawInterrupts = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 59), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssRawInterrupts.setDescription('Number of interrupts processed')
ssRawContexts = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 60), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssRawContexts.setDescription('Number of context switches')
ssCpuRawSoftIRQ = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 61), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawSoftIRQ.setDescription("The number of 'ticks' (typically 1/100s) spent\n         processing software interrupts.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssRawSwapIn = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 62), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssRawSwapIn.setDescription('Number of blocks swapped in')
ssRawSwapOut = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 63), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssRawSwapOut.setDescription('Number of blocks swapped out')
ssCpuRawSteal = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 64), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawSteal.setDescription("The number of 'ticks' (typically 1/100s) spent\n         by the hypervisor code to run other VMs even\n         though the CPU in the current VM had something runnable.\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawGuest = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 65), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawGuest.setDescription("The number of 'ticks' (typically 1/100s) spent\n         by the CPU to run a virtual CPU (guest).\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ssCpuRawGuestNice = MibScalar((1, 3, 6, 1, 4, 1, 2021, 11, 66), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ssCpuRawGuestNice.setDescription("The number of 'ticks' (typically 1/100s) spent\n         by the CPU to run a niced virtual CPU (guest).\n\n         This object will not be implemented on hosts where\n         the underlying operating system does not measure\n         this particular CPU metric.\n\n         On a multi-processor system, the 'ssCpuRaw*'\n         counters are cumulative over all CPUs, so their\n         sum will typically be N*100 (for N processors).")
ucdTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 251))
ucdStart = NotificationType((1, 3, 6, 1, 4, 1, 2021, 251, 1)).setObjects(*())
if mibBuilder.loadTexts: ucdStart.setDescription('This trap could in principle be sent when the agent start')
ucdShutdown = NotificationType((1, 3, 6, 1, 4, 1, 2021, 251, 2)).setObjects(*())
if mibBuilder.loadTexts: ucdShutdown.setDescription('This trap is sent when the agent terminates')
fileTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 15), )
if mibBuilder.loadTexts: fileTable.setDescription('Table of monitored files.')
fileEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 15, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "fileIndex"))
if mibBuilder.loadTexts: fileEntry.setDescription('Entry of file')
fileIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fileIndex.setDescription('Index of file')
fileName = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fileName.setDescription('Filename')
fileSize = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 3), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: fileSize.setDescription('Size of file (kB)')
fileMax = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 4), Integer32()).setUnits('kB').setMaxAccess("readonly")
if mibBuilder.loadTexts: fileMax.setDescription('Limit of filesize (kB)')
fileErrorFlag = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fileErrorFlag.setDescription('Limit exceeded flag')
fileErrorMsg = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 15, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fileErrorMsg.setDescription('Filesize error message')
logMatch = MibIdentifier((1, 3, 6, 1, 4, 1, 2021, 16))
logMatchMaxEntries = MibScalar((1, 3, 6, 1, 4, 1, 2021, 16, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchMaxEntries.setDescription('The maximum number of logmatch entries\n\t\tthis snmpd daemon can support.')
logMatchTable = MibTable((1, 3, 6, 1, 4, 1, 2021, 16, 2), )
if mibBuilder.loadTexts: logMatchTable.setDescription('Table of monitored files.')
logMatchEntry = MibTableRow((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1), ).setIndexNames((0, "UCD-SNMP-MIB", "logMatchIndex"))
if mibBuilder.loadTexts: logMatchEntry.setDescription('Entry of file')
logMatchIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchIndex.setDescription('Index of logmatch')
logMatchName = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchName.setDescription('logmatch instance name')
logMatchFilename = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchFilename.setDescription('filename to be logmatched')
logMatchRegEx = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchRegEx.setDescription('regular expression')
logMatchGlobalCounter = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchGlobalCounter.setDescription('global count of matches')
logMatchGlobalCount = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchGlobalCount.setDescription('Description.')
logMatchCurrentCounter = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchCurrentCounter.setDescription('Regex match counter. This counter will\n\t\tbe reset with each logfile rotation.')
logMatchCurrentCount = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 8), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchCurrentCount.setDescription('Description.')
logMatchCounter = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchCounter.setDescription('Regex match counter. This counter will\n\t\tbe reset with each read')
logMatchCount = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 10), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchCount.setDescription('Description.')
logMatchCycle = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 11), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchCycle.setDescription('time between updates (if not queried) in seconds')
logMatchErrorFlag = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 100), UCDErrorFlag()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchErrorFlag.setDescription('errorflag: is this line configured correctly?')
logMatchRegExCompilation = MibTableColumn((1, 3, 6, 1, 4, 1, 2021, 16, 2, 1, 101), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: logMatchRegExCompilation.setDescription('message of regex precompilation')
mibBuilder.exportSymbols("UCD-SNMP-MIB", ucdavis=ucdavis, versionClearCache=versionClearCache, fileName=fileName, memTotalSwapTXT=memTotalSwapTXT, snmperrIndex=snmperrIndex, logMatchCounter=logMatchCounter, logMatchCycle=logMatchCycle, dskAvailHigh=dskAvailHigh, logMatchCurrentCount=logMatchCurrentCount, extNames=extNames, snmperrErrorFlag=snmperrErrorFlag, extResult=extResult, ucdInternal=ucdInternal, ssSysContext=ssSysContext, ssRawInterrupts=ssRawInterrupts, logMatchMaxEntries=logMatchMaxEntries, ssIORawSent=ssIORawSent, prErrFix=prErrFix, laConfig=laConfig, versionCDate=versionCDate, versionRestartAgent=versionRestartAgent, irix=irix, memIndex=memIndex, memTotalSwap=memTotalSwap, ssCpuRawNice=ssCpuRawNice, laLoadFloat=laLoadFloat, ucdShutdown=ucdShutdown, memShared=memShared, memCached=memCached, PYSNMP_MODULE_ID=ucdavis, memSwapErrorMsg=memSwapErrorMsg, snmperrErrMessage=snmperrErrMessage, logMatchErrorFlag=logMatchErrorFlag, memUsedRealTXT=memUsedRealTXT, mrEntry=mrEntry, dskUsedHigh=dskUsedHigh, extErrFixCmd=extErrFixCmd, version=version, dskPath=dskPath, dskErrorFlag=dskErrorFlag, UCDErrorFix=UCDErrorFix, ssIOReceive=ssIOReceive, ssCpuUser=ssCpuUser, extIndex=extIndex, extEntry=extEntry, versionSavePersistentData=versionSavePersistentData, mrModuleName=mrModuleName, ssErrorName=ssErrorName, memUsedSwapTXT=memUsedSwapTXT, ssCpuRawGuestNice=ssCpuRawGuestNice, versionDoDebugging=versionDoDebugging, dragonfly=dragonfly, memMinimumSwap=memMinimumSwap, ucdExperimental=ucdExperimental, ssIOSent=ssIOSent, logMatchTable=logMatchTable, prErrFixCmd=prErrFixCmd, laNames=laNames, dskEntry=dskEntry, dskAvail=dskAvail, snmperrs=snmperrs, versionUpdateConfig=versionUpdateConfig, versionConfigureOptions=versionConfigureOptions, fileEntry=fileEntry, ssSwapIn=ssSwapIn, logMatchCurrentCounter=logMatchCurrentCounter, ssIndex=ssIndex, prErrorFlag=prErrorFlag, memTotalReal=memTotalReal, fileTable=fileTable, memSwapError=memSwapError, dskUsed=dskUsed, ssSwapOut=ssSwapOut, memBuffer=memBuffer, macosx=macosx, extErrFix=extErrFix, dskUsedLow=dskUsedLow, memAvailRealTXT=memAvailRealTXT, versionIndex=versionIndex, versionIdent=versionIdent, ssCpuRawKernel=ssCpuRawKernel, ssCpuRawSystem=ssCpuRawSystem, laIndex=laIndex, osf=osf, prEntry=prEntry, laLoadInt=laLoadInt, ssCpuRawInterrupt=ssCpuRawInterrupt, snmperrNames=snmperrNames, UCDErrorFlag=UCDErrorFlag, dskDevice=dskDevice, memAvailSwapTXT=memAvailSwapTXT, logMatchRegEx=logMatchRegEx, sunos4=sunos4, logMatchIndex=logMatchIndex, dskMinPercent=dskMinPercent, hpux10=hpux10, ssCpuRawIdle=ssCpuRawIdle, prTable=prTable, dskIndex=dskIndex, versionDate=versionDate, dskMinimum=dskMinimum, laErrMessage=laErrMessage, laErrorFlag=laErrorFlag, ssCpuRawSoftIRQ=ssCpuRawSoftIRQ, freebsd=freebsd, ssRawSwapIn=ssRawSwapIn, logMatchGlobalCount=logMatchGlobalCount, openbsd=openbsd, solaris=solaris, dskTotal=dskTotal, ucdTraps=ucdTraps, ssRawContexts=ssRawContexts, ssIORawReceived=ssIORawReceived, ssRawSwapOut=ssRawSwapOut, prIndex=prIndex, fileErrorMsg=fileErrorMsg, fileMax=fileMax, hpux9=hpux9, netbsd1=netbsd1, linux=linux, prMax=prMax, prErrMessage=prErrMessage, dskTotalHigh=dskTotalHigh, ssCpuRawSteal=ssCpuRawSteal, logMatchCount=logMatchCount, fileIndex=fileIndex, aix=aix, versionTag=versionTag, logMatchEntry=logMatchEntry, extOutput=extOutput, laTable=laTable, ssCpuRawGuest=ssCpuRawGuest, ssCpuRawUser=ssCpuRawUser, extCommand=extCommand, ssCpuSystem=ssCpuSystem, ssCpuRawWait=ssCpuRawWait, memAvailReal=memAvailReal, mrTable=mrTable, logMatchFilename=logMatchFilename, mrIndex=mrIndex, fileErrorFlag=fileErrorFlag, logMatchName=logMatchName, systemStats=systemStats, memTotalRealTXT=memTotalRealTXT, dskAvailLow=dskAvailLow, Float=Float, logMatchRegExCompilation=logMatchRegExCompilation, extTable=extTable, prNames=prNames, prMin=prMin, memory=memory, dskErrorMsg=dskErrorMsg, laEntry=laEntry, ucdStart=ucdStart, ucdSnmpAgent=ucdSnmpAgent, dskPercentNode=dskPercentNode, logMatchGlobalCounter=logMatchGlobalCounter, logMatch=logMatch, dskTable=dskTable, memErrorName=memErrorName, laLoad=laLoad, prCount=prCount, win32=win32, fileSize=fileSize, bsdi=bsdi, dskTotalLow=dskTotalLow, unknown=unknown, hpux11=hpux11, memTotalFree=memTotalFree, dskPercent=dskPercent, ssCpuIdle=ssCpuIdle, ultrix=ultrix, memAvailSwap=memAvailSwap, ssSysInterrupts=ssSysInterrupts)
